@@ -463,8 +463,8 @@ earth_plotmodsel <- function(
                 labs <- c(labs, substr(names(object$cv.list)[ifold], 5, 15))
             }
             cex <- .6
-            text(x=x, y=TeachingDemos::spread.labs(y,
-                            mindiff=1.2 * strheight("X")),
+            text(x=x,
+                 y=TeachingDemos::spread.labs(y, mindiff=1.2 * strheight("X")),
                  labels=labs, cex=cex, col=col.oof.labs[ifold], xpd=NA)
         }
         if(is.specified(col.pch.max.oof.rsq) || is.specified(col.pch.cv.rsq)) {
